==> polyv-java-live-sdk-1.1.11-sources.jar: net/polyv/live/v1/constant/LiveConstant.java <==
package net.polyv.live.v1.constant;

/**
 * 直播常量类
 * @author: thomas
 **/
public class LiveConstant {
    
    public static final String UTF8 = "UTF-8";
    
    public enum SceneType {
        /**
         * 频道场景：三分屏
         */
        PPT("ppt"),
        /**
         * 频道场景：普通直播
         */
        ALONE("alone"),
        /**
         * 频道场景：大班课
         */
        TOPCLASS("topclass"),
        /**
         * 频道场景：研讨会
         */
        SEMINAR("seminar");
        
        private String desc;
        
        private SceneType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    public enum PPTStatus {
        /**
         * 课件重置状态值：等待处理
         */
        WAITING("waiting"),
        /**
         * 课件重置状态值：处理中
         */
        PROCESS("process"),
        /**
         * 课件重置状态值：重制成功
         */
        SUCCESS("success"),
        /**
         * 课件重置状态值：重制失败
         */
        FAIL("fail"),
        /**
         * 课件重置状态值：上传点播成功
         */
        UPLOADED("uploaded"),
        /**
         * 课件重置状态值：上传点播失败
         */
        UPLOADFAILED("uploadFailed");
        
        private String desc;
        
        private PPTStatus(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    public enum AuthType {
        /**
         * 观看条件：付费观看
         */
        PAY("pay"),
        /**
         * 观看条件：验证码观看
         */
        CODE("code"),
        /**
         * 观看条件：白名单观看
         */
        PHONE("phone"),
        /**
         * 观看条件：登记观看
         */
        INFO("info"),
        /**
         * 观看条件：自定义授权观看
         */
        CUSTOM("custom"),
        /**
         * 观看条件：外部授权
         */
        EXTERNAL("external"),
        /**
         * 观看条件：直接授权
         */
        DIRECT("direct");
        
        private String desc;
        
        private AuthType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    public enum Role {
        /**
         * 角色：teacher
         */
        TEACHER("teacher"),
        /**
         * 角色：admin
         */
        ADMIN("admin"),
        /**
         * 角色：guest
         */
        GUEST("guest"),
        /**
         * 角色：assistant
         */
        ASSISTANT("assistant"),
        /**
         * 角色：viewer
         */
        VIEWER("viewer");
        
        private String desc;
        
        private Role(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    
    /**
     * 问卷答题类型
     */
    public enum QuestionType {
        //"题目类型,R为单选，C为多选，Q为问答
        RADIO("R"), CHECK("C"), QUESTION("Q");
        
        private String type;
        
        private QuestionType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 通用条件判断
     */
    public enum Flag {
        //Y=YES , N=NO
        YES("Y"), NO("N"), AOTU_PLAY("1"), MANUAL_PLAY("0");
        
        private String flag;
        
        private Flag(String flag) {
            this.flag = flag;
        }
        
        public String getFlag() {
            return flag;
        }
    }
    
    /**
     * 是否自动播放，0/1，默认1
     */
    public enum AutoPlay {
        //	是否自动播放，0/1，默认1
        AOTU_PLAY(1), MANUAL_PLAY(0);
        
        private Integer flag;
        
        private AutoPlay(Integer flag) {
            this.flag = flag;
        }
        
        public Integer getFlag() {
            return flag;
        }
    }
    
    /**
     * 三分屏频道的观看布局，不设置会使用账号的通用设置，取值：ppt 文档为主，video 视频为主
     */
    public enum WatchLayout {
        //	三分屏频道的观看布局，不设置会使用账号的通用设置，取值：ppt 文档为主，video 视频为主
        PPT("ppt"), VIDEO("video");
        
        private String flag;
        
        private WatchLayout(String flag) {
            this.flag = flag;
        }
        
        public String getFlag() {
            return flag;
        }
    }
    
    /**
     * logo位置，取值为为左上角(tl)、右上角(tr)、左下角(bl)、右下角(br)
     */
    public enum LogoPosition {
        //	logo位置，取值为为左上角(tl)、右上角(tr)、左下角(bl)、右下角(br)
        TL("tl"), TR("tr"), BL("bl"), BR("br");
        
        private String position;
        
        private LogoPosition(String position) {
            this.position = position;
        }
        
        public String getPosition() {
            return position;
        }
    }
    
    /**
     * 广告类型,NONE-无广告，IMAGE-图片广告，FLV-视频广告
     */
    public enum HeadAdvertType {
        //	广告类型,NONE-无广告，IMAGE-图片广告，FLV-视频广告
        NONE("NONE"), IMAGE("IMAGE"), FLV("FLV");
        
        private String desc;
        
        private HeadAdvertType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    
    /**
     * 禁言类型
     */
    public enum BannedType {
        //禁言类型,ip/userId
        IP("ip"), USER_ID("userId"), BADWORD("badword");
        
        private String type;
        
        private BannedType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 聊天记录状态，默认：pass(已审核)，审核状态，pass：已审核，censor：审核中和删除
     */
    public enum ChatStatus {
        //聊天记录状态，默认：pass(已审核)，审核状态，pass：已审核，censor：审核中和删除
        PASS("pass"), CENSOR("censor");
        
        private String type;
        
        private ChatStatus(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 用户类型，可以选择多个类型，用英文逗号隔开。可选值包括：
     * slice:云课堂学员
     * teacher:讲师
     * guest:嘉宾
     * manager:管理员
     * assistant:助教
     * viewer:特邀观众
     * monitor:场监
     * attendee:研讨会参与者
     * student:普通直播观众
     */
    public enum UserType {
        //用户类型，可以选择多个类型，用英文逗号隔开。可选值包括：
        //slice:云课堂学员
        //teacher:讲师
        //guest:嘉宾
        //manager:管理员
        //assistant:助教
        //viewer:特邀观众
        //monitor:场监
        //attendee:研讨会参与者
        //student:普通直播观众
        SLICE("slice"), TEACHER("teacher"), GUEST("guest"), MANAGER("manager"), ASSISTANT("assistant"),
        VIEWER("viewer"), MONITOR("monitor"), ATTENDEE("attendee"), STUDENT("studnet");
        
        private String type;
        
        private UserType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 功能开关类型
     */
    public enum ChannelSwitch {
        /**
         * 是否关闭系统观看页，Y时表示关闭
         */
        IS_CLOSE_PREVIEW("isClosePreview")
        /**
         * 是否开启移动端系统观看页
         */
        , MOBILE_WATCH("mobileWatch")
        /**
         * 是否开启移动端音视频切换
         */
        , MOBILE_AUDIO("mobileAudio")
        /**
         * 是否开启播放器自动播放功能
         */
        , AUTO_PLAY("autoPlay")
        /**
         * 是否开启预约功能
         */
        , BOOKING("booking")
        /**
         * 是否开启红包功能
         */
        , RED_PACK("redPack")
        /**
         * 是否开启分享功能
         */
        , SHARE_BTN_ENABLED("shareBtnEnabled")
        /**
         * 是否开启聊天室
         */
        , CHAT("chat")
        /**
         * 是否关闭在线列表，Y时表示关闭
         */
        , CLOSE_CHATER_LIST("closeChaterList")
        /**
         * 是否开启咨询提问
         */
        , CONSULTING_MENU("consultingMenu")
        /**
         * 是否关闭弹幕功能，Y时表示关闭
         */
        , CLOSE_DANMU("closeDanmu")
        /**
         * 是否开启点赞语功能
         */
        , PRAISE("praise")
        /**
         * 是否开启欢迎语功能
         */
        , WELCOME("welcome")
        /**
         * 是否开启观众发送图片
         */
        , VIEWER_SEND_IMG_ENABLED("viewerSendImgEnabled")
        /**
         * 是否开启问答功能
         */
        , QA_MENU_ENABLED("qaMenuEnabled")
        /**
         * 过滤聊天室管理员的聊天消息开关，即观看页聊天室只看主持人开关
         */
        , FILTER_MANAGER_MSG_ENABLED("filterManagerMsgEnabled")
        /**
         * 显示自定义消息开关
         */
        , SHOW_CUSTOM_MESSAGE_ENABLED("showCustomMessageEnabled")
        /**
         * 在线人数开关
         */
        , CHAT_ONLINE_NUMBER_ENABLE("chatOnlineNumberEnable");
        
        private String desc;
        
        private ChannelSwitch(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    /**
     * 频道通用开关类型
     */
    public enum GlobalEnabledType {
        /**
         * 观看条件设置;观看页管理-观看条件
         */
        AUTH("auth")
        /**
         * 功能开关设置;直播间管理-功能开关
         */
        , SWITCH("switch")
        /**
         * 跑马灯设置;播放器管理-防录屏跑马灯
         */
        , MARQUEE("marquee")
        /**
         * 播放限制设置;播放器管理-播放限制
         */
        , RESTRICT("restrict")
        /**
         * 打赏设置;观看页管理-打赏设置
         */
        , DONATE("donate")
        /**
         * 广告设置;观看也管理-营销设置-广告
         */
        , ADVERT("advert")
        /**
         * 回调设置;
         */
        , CALLBACK("callback")
        /**
         * 播放器设置;
         */
        , PLAYER("player");
        
        private String desc;
        
        private GlobalEnabledType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    /**
     * 页面菜单类型
     */
    public enum MenuType {
        //desc：直播介绍;chat：互动聊天;quiz：咨询提问;text：图文菜单;iframe：推广外链;qa：问答;buy：商品列表;invite：邀请榜
        
        DESC("desc", "直播介绍"), CHAT("chat", "互动聊天"), QUIZ("quiz", "咨询提问"), TEXT("text", "图文菜单"),
        IFRAME("iframe", "推广外链"), QA("qa", "问答"), BUY("buy", "商品列表"), INVITE("invite", "邀请榜");
        
        private final String type;
        private final String content;
        
        private MenuType(String type, String content) {
            this.type = type;
            this.content = content;
        }
        
        public String getType() {
            return type;
        }
        
        public String getContent() {
            return content;
        }
    }
    
    /**
     * 频道商品库 商品类型
     * normal:普通商品
     * finance:金融商品
     */
    public enum ProductType {
        
        NORMAL("normal"), FINANCE("finance");
        
        private final String type;
        
        private ProductType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 频道商品库 上下架状态、列表顺序
     * 1：上架，2：下架，10：上移，20：下移
     */
    public enum ProductStatus {
        
        UP(1), DOWN(2), MOVE_UP(10), MOVE_DOWN(20);
        
        private final Integer type;
        
        private ProductStatus(Integer type) {
            this.type = type;
        }
        
        public Integer getType() {
            return type;
        }
    }
}

==> polyv-java-live-sdk-1.1.14-sources.jar: net/polyv/live/v1/constant/LiveConstant.java <==
package net.polyv.live.v1.constant;

/**
 * 直播常量类
 * @author: thomas
 **/
public class LiveConstant {
    
    public static final String UTF8 = "UTF-8";
    
    public enum SceneType {
        /**
         * 频道场景：三分屏
         */
        PPT("ppt"),
        /**
         * 频道场景：普通直播
         */
        ALONE("alone"),
        /**
         * 频道场景：大班课
         */
        TOPCLASS("topclass"),
        /**
         * 频道场景：研讨会
         */
        SEMINAR("seminar");
        
        private String desc;
        
        private SceneType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    public enum PPTStatus {
        /**
         * 课件重置状态值：等待处理
         */
        WAITING("waiting"),
        /**
         * 课件重置状态值：处理中
         */
        PROCESS("process"),
        /**
         * 课件重置状态值：重制成功
         */
        SUCCESS("success"),
        /**
         * 课件重置状态值：重制失败
         */
        FAIL("fail"),
        /**
         * 课件重置状态值：上传点播成功
         */
        UPLOADED("uploaded"),
        /**
         * 课件重置状态值：上传点播失败
         */
        UPLOADFAILED("uploadFailed");
        
        private String desc;
        
        private PPTStatus(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    public enum AuthType {
        /**
         * 观看条件：付费观看
         */
        PAY("pay"),
        /**
         * 观看条件：验证码观看
         */
        CODE("code"),
        /**
         * 观看条件：白名单观看
         */
        PHONE("phone"),
        /**
         * 观看条件：登记观看
         */
        INFO("info"),
        /**
         * 观看条件：自定义授权观看
         */
        CUSTOM("custom"),
        /**
         * 观看条件：外部授权
         */
        EXTERNAL("external"),
        /**
         * 观看条件：直接授权
         */
        DIRECT("direct");
        
        private String desc;
        
        private AuthType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    public enum Role {
        /**
         * 角色：teacher
         */
        TEACHER("teacher"),
        /**
         * 角色：admin
         */
        ADMIN("admin"),
        /**
         * 角色：guest
         */
        GUEST("guest"),
        /**
         * 角色：assistant
         */
        ASSISTANT("assistant"),
        /**
         * 角色：viewer
         */
        VIEWER("viewer");
        
        private String desc;
        
        private Role(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    
    /**
     * 问卷答题类型
     */
    public enum QuestionType {
        //"题目类型,R为单选，C为多选，Q为问答
        RADIO("R"), CHECK("C"), QUESTION("Q");
        
        private String type;
        
        private QuestionType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 通用条件判断
     */
    public enum Flag {
        //Y=YES , N=NO
        YES("Y"), NO("N"), AOTU_PLAY("1"), MANUAL_PLAY("0");
        
        private String flag;
        
        private Flag(String flag) {
            this.flag = flag;
        }
        
        public String getFlag() {
            return flag;
        }
    }
    
    /**
     * 是否自动播放，0/1，默认1
     */
    public enum AutoPlay {
        //	是否自动播放，0/1，默认1
        AOTU_PLAY(1), MANUAL_PLAY(0);
        
        private Integer flag;
        
        private AutoPlay(Integer flag) {
            this.flag = flag;
        }
        
        public Integer getFlag() {
            return flag;
        }
    }
    
    /**
     * 三分屏频道的观看布局，不设置会使用账号的通用设置，取值：ppt 文档为主，video 视频为主
     */
    public enum WatchLayout {
        //	三分屏频道的观看布局，不设置会使用账号的通用设置，取值：ppt 文档为主，video 视频为主
        PPT("ppt"), VIDEO("video");
        
        private String flag;
        
        private WatchLayout(String flag) {
            this.flag = flag;
        }
        
        public String getFlag() {
            return flag;
        }
    }
    
    /**
     * logo位置，取值为为左上角(tl)、右上角(tr)、左下角(bl)、右下角(br)
     */
    public enum LogoPosition {
        //	logo位置，取值为为左上角(tl)、右上角(tr)、左下角(bl)、右下角(br)
        TL("tl"), TR("tr"), BL("bl"), BR("br");
        
        private String position;
        
        private LogoPosition(String position) {
            this.position = position;
        }
        
        public String getPosition() {
            return position;
        }
    }
    
    /**
     * 广告类型,NONE-无广告，IMAGE-图片广告，FLV-视频广告
     */
    public enum HeadAdvertType {
        //	广告类型,NONE-无广告，IMAGE-图片广告，FLV-视频广告
        NONE("NONE"), IMAGE("IMAGE"), FLV("FLV");
        
        private String desc;
        
        private HeadAdvertType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    
    /**
     * 禁言类型
     */
    public enum BannedType {
        //禁言类型,ip/userId
        IP("ip"), USER_ID("userId"), BADWORD("badword");
        
        private String type;
        
        private BannedType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 聊天记录状态，默认：pass(已审核)，审核状态，pass：已审核，censor：审核中和删除
     */
    public enum ChatStatus {
        //聊天记录状态，默认：pass(已审核)，审核状态，pass：已审核，censor：审核中和删除
        PASS("pass"), CENSOR("censor");
        
        private String type;
        
        private ChatStatus(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 用户类型，可以选择多个类型，用英文逗号隔开。可选值包括：
     * slice:云课堂学员
     * teacher:讲师
     * guest:嘉宾
     * manager:管理员
     * assistant:助教
     * viewer:特邀观众
     * monitor:场监
     * attendee:研讨会参与者
     * student:普通直播观众
     */
    public enum UserType {
        //用户类型，可以选择多个类型，用英文逗号隔开。可选值包括：
        //slice:云课堂学员
        //teacher:讲师
        //guest:嘉宾
        //manager:管理员
        //assistant:助教
        //viewer:特邀观众
        //monitor:场监
        //attendee:研讨会参与者
        //student:普通直播观众
        SLICE("slice"), TEACHER("teacher"), GUEST("guest"), MANAGER("manager"), ASSISTANT("assistant"),
        VIEWER("viewer"), MONITOR("monitor"), ATTENDEE("attendee"), STUDENT("studnet");
        
        private String type;
        
        private UserType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 功能开关类型
     */
    public enum ChannelSwitch {
        /**
         * 是否关闭系统观看页，Y时表示关闭
         */
        IS_CLOSE_PREVIEW("isClosePreview")
        /**
         * 是否开启移动端系统观看页
         */
        , MOBILE_WATCH("mobileWatch")
        /**
         * 是否开启移动端音视频切换
         */
        , MOBILE_AUDIO("mobileAudio")
        /**
         * 是否开启播放器自动播放功能
         */
        , AUTO_PLAY("autoPlay")
        /**
         * 是否开启预约功能
         */
        , BOOKING("booking")
        /**
         * 是否开启红包功能
         */
        , RED_PACK("redPack")
        /**
         * 是否开启分享功能
         */
        , SHARE_BTN_ENABLED("shareBtnEnabled")
        /**
         * 是否开启聊天室
         */
        , CHAT("chat")
        /**
         * 是否关闭在线列表，Y时表示关闭
         */
        , CLOSE_CHATER_LIST("closeChaterList")
        /**
         * 是否开启咨询提问
         */
        , CONSULTING_MENU("consultingMenu")
        /**
         * 是否关闭弹幕功能，Y时表示关闭
         */
        , CLOSE_DANMU("closeDanmu")
        /**
         * 是否开启点赞语功能
         */
        , PRAISE("praise")
        /**
         * 是否开启欢迎语功能
         */
        , WELCOME("welcome")
        /**
         * 是否开启观众发送图片
         */
        , VIEWER_SEND_IMG_ENABLED("viewerSendImgEnabled")
        /**
         * 是否开启问答功能
         */
        , QA_MENU_ENABLED("qaMenuEnabled")
        /**
         * 过滤聊天室管理员的聊天消息开关，即观看页聊天室只看主持人开关
         */
        , FILTER_MANAGER_MSG_ENABLED("filterManagerMsgEnabled")
        /**
         * 显示自定义消息开关
         */
        , SHOW_CUSTOM_MESSAGE_ENABLED("showCustomMessageEnabled")
        /**
         * 在线人数开关
         */
        , CHAT_ONLINE_NUMBER_ENABLE("chatOnlineNumberEnable");
        
        private String desc;
        
        private ChannelSwitch(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    /**
     * 频道通用开关类型
     */
    public enum GlobalEnabledType {
        /**
         * 观看条件设置;观看页管理-观看条件
         */
        AUTH("auth")
        /**
         * 功能开关设置;直播间管理-功能开关
         */
        , SWITCH("switch")
        /**
         * 跑马灯设置;播放器管理-防录屏跑马灯
         */
        , MARQUEE("marquee")
        /**
         * 播放限制设置;播放器管理-播放限制
         */
        , RESTRICT("restrict")
        /**
         * 打赏设置;观看页管理-打赏设置
         */
        , DONATE("donate")
        /**
         * 广告设置;观看也管理-营销设置-广告
         */
        , ADVERT("advert")
        /**
         * 回调设置;
         */
        , CALLBACK("callback")
        /**
         * 播放器设置;
         */
        , PLAYER("player");
        
        private String desc;
        
        private GlobalEnabledType(String desc) {
            this.desc = desc;
        }
        
        public String getDesc() {
            return desc;
        }
    }
    
    /**
     * 页面菜单类型
     */
    public enum MenuType {
        //desc：直播介绍;chat：互动聊天;quiz：咨询提问;text：图文菜单;iframe：推广外链;qa：问答;buy：商品列表;invite：邀请榜
        
        DESC("desc", "直播介绍"), CHAT("chat", "互动聊天"), QUIZ("quiz", "咨询提问"), TEXT("text", "图文菜单"),
        IFRAME("iframe", "推广外链"), QA("qa", "问答"), BUY("buy", "商品列表"), INVITE("invite", "邀请榜");
        
        private final String type;
        private final String content;
        
        private MenuType(String type, String content) {
            this.type = type;
            this.content = content;
        }
        
        public String getType() {
            return type;
        }
        
        public String getContent() {
            return content;
        }
    }
    
    /**
     * 频道商品库 商品类型
     * normal:普通商品
     * finance:金融商品
     */
    public enum ProductType {
        
        NORMAL("normal"), FINANCE("finance");
        
        private final String type;
        
        private ProductType(String type) {
            this.type = type;
        }
        
        public String getType() {
            return type;
        }
    }
    
    /**
     * 频道商品库 上下架状态、列表顺序
     * 1：上架，2：下架，10：上移，20：下移
     */
    public enum ProductStatus {
        
        UP(1), DOWN(2), MOVE_UP(10), MOVE_DOWN(20);
        
        private final Integer type;
        
        private ProductStatus(Integer type) {
            this.type = type;
        }
        
        public Integer getType() {
            return type;
        }
    }
    
    /**
     * 防录屏方式
     * marquee：跑马灯
     * watermark：水印
     */
    public enum AntiRecordType {
        
        /**
         * 跑马灯
         */
        MARQUEE("marquee"),
        
        /**
         * 水印
         */
        WATERMARK("watermark");
        
        private final String value;
        
        private AntiRecordType(String value) {
            this.value = value;
        }
        
        public String getValue() {
            return value;
        }
    }
    
    /**
     * 防录屏类型
     * fixed：固定值
     * nickname：登陆用户名
     * diyurl：URL自定义跑马灯
     */
    public enum ModelType {
        
        /**
         * 固定值
         */
        Fixed("fixed"),
        
        /**
         * 登陆名
         */
        NickName("nickname"),
        
        /**
         * 自定义URL
         */
        CustomUrl("diyurl");
        
        private final String value;
        
        private ModelType(String value) {
            this.value = value;
        }
        
        public String getValue() {
            return value;
        }
    }
    
    /**
     * 跑马灯显示方式
     * roll：滚动
     * flicker：闪烁
     */
    public enum ShowMode {
        
        /**
         * 滚动
         */
        ROLL("roll"),
        
        /**
         * 闪烁
         */
        FLICKER("flicker");
        
        private final String value;
        
        private ShowMode(String value) {
            this.value = value;
        }
        
        public String getValue() {
            return value;
        }
    }
    
    /**
     * 防录屏水印字体大小
     * small：小
     * middle：中
     * large：大
     */
    public enum WatermarkFontSize {
        
        /**
         * 小
         */
        SMALL("small"),
        
        /**
         * 中
         */
        MIDDLE("middle"),
        
        /**
         * 大
         */
        LARGE("large");
        
        private final String value;
        
        private WatermarkFontSize(String value) {
            this.value = value;
        }
        
        public String getValue() {
            return value;
        }
    }
    
    /**
     * 频道重置课件配置 视频布局方式
     * 0：三分屏
     * 1：纯文档
     * 2：画中画
     */
    public enum PPTRecordType {
        
        /**
         * 三分屏
         */
        THREESCREEN(0),
        
        /**
         * 纯文档
         */
        DOCUMENT(1),
        
        /**
         * 画中画
         */
        PICTURE(2);
        
        private final Integer type;
        
        private PPTRecordType(Integer type) {
            this.type = type;
        }
        
        public Integer getValue() {
            return type;
        }
    }
    
    /**
     * 频道重置课件配置 摄像头画面比例，新版重制有效
     * 0：画面比例16:9
     * 1：画面比例4:3
     */
    public enum PPTRecordRatio {
        
        /**
         * 画面比例16:9
         */
        RATIO_16_9("0"),
        
        /**
         * 画面比例4:3
         */
        RATIO_4_3("1");
        
        private final String type;
        
        private PPTRecordRatio(String type) {
            this.type = type;
        }
        
        public String getValue() {
            return type;
        }
    }
}
